==> dojo-1.11.4.tgz: package/cldr/nls/id/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-second-relative+0": "sekarang",
	"field-weekday": "Hari dalam Seminggu",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-tue-relative+-1": "Selasa lalu",
	"days-format-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "Jumat lalu",
	"field-wed-relative+-1": "Rabu lalu",
	"months-format-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Sya'ban",
		"Ramadhan",
		"Syawal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormat-full": "EEEE, dd MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-Md": "d/M",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Sya'ban",
		"Ramadhan",
		"Syawal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "Tahun",
	"field-hour": "Jam",
	"months-format-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Syaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-sat-relative+0": "Sabtu ini",
	"field-sat-relative+1": "Sabtu berikutnya",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "hari ini",
	"field-thu-relative+0": "Kamis ini",
	"field-day-relative+1": "besok",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "lusa",
	"months-standAlone-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Syaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "Minggu ini",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "Minggu berikutnya",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"AH"
	],
	"field-minute": "Menit",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "kemarin",
	"dayPeriods-format-narrow-am": "AM",
	"field-day-relative+-2": "kemarin lusa",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"field-fri-relative+0": "Jumat ini",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-day": "Hari",
	"days-format-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-zone": "Zona Waktu",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "tahun lalu",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"days-format-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "Bulan",
	"dateFormatItem-MMM": "LLL",
	"days-standAlone-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"dateFormat-short": "d/M/y GGGGG",
	"field-second": "Detik",
	"field-sat-relative+-1": "Sabtu lalu",
	"field-sun-relative+-1": "Minggu lalu",
	"field-month-relative+0": "bulan ini",
	"field-month-relative+1": "Bulan berikutnya",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Minggu",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "tahun ini",
	"field-week-relative+-1": "minggu lalu",
	"field-year-relative+1": "tahun depan",
	"dateFormatItem-yyyyM": "M/y G",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-GyMMM": "MMM y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "minggu ini",
	"field-week-relative+1": "Minggu berikutnya"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/id/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-second-relative+0": "sekarang",
	"field-weekday": "Hari dalam Seminggu",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-tue-relative+-1": "Selasa lalu",
	"days-format-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "Jumat lalu",
	"field-wed-relative+-1": "Rabu lalu",
	"months-format-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Sya’ban",
		"Ramadhan",
		"Syawal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormat-full": "EEEE, dd MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-Md": "d/M",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Sya’ban",
		"Ramadhan",
		"Syawal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "Tahun",
	"field-hour": "Jam",
	"months-format-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Syaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-sat-relative+0": "Sabtu ini",
	"field-sat-relative+1": "Sabtu berikutnya",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "hari ini",
	"field-thu-relative+0": "Kamis ini",
	"field-day-relative+1": "besok",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "lusa",
	"months-standAlone-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Syaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "hari Minggu ini",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "hari Minggu berikutnya",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"AH"
	],
	"field-minute": "Menit",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "kemarin",
	"dayPeriods-format-narrow-am": "AM",
	"field-day-relative+-2": "kemarin lusa",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"field-fri-relative+0": "Jumat ini",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-day": "Hari",
	"days-format-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-zone": "Zona Waktu",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "tahun lalu",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"days-format-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "Bulan",
	"dateFormatItem-MMM": "LLL",
	"days-standAlone-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"dateFormat-short": "d/M/y GGGGG",
	"field-second": "Detik",
	"field-sat-relative+-1": "Sabtu lalu",
	"field-sun-relative+-1": "hari Minggu lalu",
	"field-month-relative+0": "bulan ini",
	"field-month-relative+1": "Bulan berikutnya",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Minggu",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "tahun ini",
	"field-week-relative+-1": "minggu lalu",
	"field-year-relative+1": "tahun depan",
	"dateFormatItem-yyyyM": "M/y G",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-GyMMM": "MMM y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "minggu ini",
	"field-week-relative+1": "minggu berikutnya"
}
//end v1.x content
);
